=========
Tutorials
=========

The following are some tutorials which show and explain how to use the toolbox
to solve some real problems.  They goes in increasing degree of difficulty. If
you have never used the toolbox before, you are encouraged to follow them in
order as they build one upon the other.

.. toctree::
    simple
    compressed_sensing_forward_backward
    compressed_sensing_douglas_rachford
    reconstruction
    denoising
